==> waldur_api_client-0.1.0-py3-none-any.whl: waldur_api_client/api/notification_messages_templates/notification_messages_templates_create.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.notification_template_detail_serializers import NotificationTemplateDetailSerializers
from ...models.notification_template_detail_serializers_request import NotificationTemplateDetailSerializersRequest
from ...types import Response


def _get_kwargs(
    *,
    body: NotificationTemplateDetailSerializersRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api/notification-messages-templates/",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[NotificationTemplateDetailSerializers]:
    if response.status_code == 201:
        response_201 = NotificationTemplateDetailSerializers.from_dict(response.json())

        return response_201
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[NotificationTemplateDetailSerializers]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> Response[NotificationTemplateDetailSerializers]:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[NotificationTemplateDetailSerializers]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> Optional[NotificationTemplateDetailSerializers]:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        NotificationTemplateDetailSerializers
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> Response[NotificationTemplateDetailSerializers]:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[NotificationTemplateDetailSerializers]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> Optional[NotificationTemplateDetailSerializers]:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        NotificationTemplateDetailSerializers
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed

==> waldur_api_client-7.7.0-py3-none-any.whl: waldur_api_client/api/notification_messages_templates/notification_messages_templates_create.py <==
from http import HTTPStatus
from typing import Any, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.notification_template_detail_serializers import NotificationTemplateDetailSerializers
from ...models.notification_template_detail_serializers_request import NotificationTemplateDetailSerializersRequest
from ...types import Response


def _get_kwargs(
    *,
    body: NotificationTemplateDetailSerializersRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api/notification-messages-templates/",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> NotificationTemplateDetailSerializers:
    if response.status_code == 201:
        response_201 = NotificationTemplateDetailSerializers.from_dict(response.json())

        return response_201
    raise errors.UnexpectedStatus(response.status_code, response.content)


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[NotificationTemplateDetailSerializers]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> Response[NotificationTemplateDetailSerializers]:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[NotificationTemplateDetailSerializers]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> NotificationTemplateDetailSerializers:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        NotificationTemplateDetailSerializers
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> Response[NotificationTemplateDetailSerializers]:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[NotificationTemplateDetailSerializers]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    body: NotificationTemplateDetailSerializersRequest,
) -> NotificationTemplateDetailSerializers:
    """
    Args:
        body (NotificationTemplateDetailSerializersRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        NotificationTemplateDetailSerializers
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed
